4. Языки / Мультиязычность — документация OMS CMS beta

# 4. Языки / Мультиязычность

Модуль для создания мультиязычного сайта.

Определить язык который выбрал пользователь можно забрав его из:

    request.session["lang"]

## 4.1. Template tags

Подключение тега. Если не указать шаблон, то будет взят по умолчанию.

    {% load lang_tags %}

    {% list_lang %}

Изменение шаблона

    {% list_lang template="lang.html" %}

Шаблон для выбора языков.

    {% for lang in languages %}
        <ul>
            <li>
                <a href="{{ lang.get_absolute_url }}">{{ lang.name }}</a>
            </li>
        </ul>
    {% endfor %}

## 4.2. Поля модели языков

> name

>   Название, отображается на сайте

> slug

>   Сокращение названия, Пример: «ru»

> is_default

>   Язык по умолчанию